<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sl">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>WLAN vključen</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>WLAN izključen</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>Caps Lock vključen</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>Caps Lock izključen</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>Numerična tipka vključena</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>Numerična tipka izključena</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>Tipka za dotik vključena</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>Tipka za dotik izključena</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>Preklop tipke za dotik</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Preklop funkcij</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>Režim letalnice vključen</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>Režim letalnice izključen</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>Izdelava balansirana</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>Uhrnavanje</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>Visoka virevna moč</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>Efekti okna omogočeni</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>Efekti okna onemogočeni</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>Napaka pri omogočanju efektov okna</translation>
    </message>
    <message>
        <source>Microphone off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Microphone on</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>